@@ -7,7 +7,6 @@ tpred<-tpred/object$high.pct*10
 xpredtemp<-rbind(xpred,object$x)
 xpredframe<-data.frame(xpredtemp)
 xpredtemp<-model.matrix(~xpredtemp,xpredframe,contrasts)
-#xpredtemp<-xpredtemp[,-1]
 
 xpred<-matrix(xpredtemp[1:nrow(xpred),],nrow=nrow(xpred))
 xpred<-matrix(xpred[,-1],nrow=nrow(xpred))
@@ -15,7 +14,7 @@ xpred<-(xpred-matrix(rep(object$xmean,times=nrow(xpred)),nrow=nrow(xpred), byrow
 predobject<-.Call('DPWeibull_predreg', PACKAGE = 'DPWeibull',
 object$alpharec,object$lambdascaled,object$betarec,xpred,tpred,alpha)
 class(predobject)<-"predddp"
-predobject$tpred<-object$predtime
+predobject$tpred<-tpred
 predobject$alpha<-alpha
 predobject
 }
@@ -39,7 +38,7 @@ object$alpharec1,object$lambdascaled1,object$betarec1,
 object$alpharec2,object$lambdascaled2,object$betarec2,object$prec,
 xpred,tpred,alpha)
 class(predobject)<-"predddpcomp"
-predobject$tpred<-object$predtime
+predobject$tpred<-tpred
 predobject$alpha<-alpha
 predobject
 }
